==> fastybird-devices-module-0.74.0.tar.gz: fastybird-devices-module-0.74.0/README.md <==
# FastyBird IoT devices module

[![Build Status](https://badgen.net/github/checks/FastyBird/devices-module/master?cache=300&style=flat-square)](https://github.com/FastyBird/devices-module/actions)
[![Licence](https://badgen.net/github/license/FastyBird/devices-module?cache=300&style=flat-square)](https://github.com/FastyBird/devices-module/blob/master/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/devices-module?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/devices-module)

![PHP](https://badgen.net/packagist/php/FastyBird/devices-module?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/devices-module/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/devices-module)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/devices-module?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/devices-module)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![JS](https://img.shields.io/badge/js-es6-blue.svg?style=flat-square)
[![JS latest stable](https://badgen.net/npm/v/@fastybird/devices-module?cache=300&style=flat-square)](https://www.npmjs.com/package/@fastybird/devices-module)
[![JS downloads total](https://badgen.net/npm/dt/@fastybird/devices-module?cache=300&style=flat-square)](https://www.npmjs.com/package/@fastybird/devices-module)
![Types](https://badgen.net/npm/types/@fastybird/devices-module?cache=300&style=flat-square)

![Python](https://badgen.net/pypi/python/fastybird-devices-module?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-devices-module?cache=300&style=flat-square)](https://pypi.org/project/fastybird-devices-module/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-devices-module?cache=300&style=flat-square)](https://pypi.org/project/fastybird-devices-module/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird IoT devices module?

Devices module is a combined [Nette framework](https://nette.org) extension, [Vuex ORM](https://vuex-orm.org) plugin
and also [Python](https://python.org) module for managing connectors and connected devices and their basic logic.

[FastyBird](https://www.fastybird.com) [IoT](https://en.wikipedia.org/wiki/Internet_of_things) devices module is
an [Apache2 licensed](http://www.apache.org/licenses/LICENSE-2.0) distributed extension, developed
in [PHP](https://www.php.net) with [Nette framework](https://nette.org), in [Typescript](https://www.typescriptlang.org)
and also in [Python](https://python.org).

### Features:

- Devices connectors management
- Devices and channels management
- Support for data [exchange bus](https://github.com/FastyBird/exchange)
- [{JSON:API}](https://jsonapi.org/) schemas for full api access
- User access [check & validation](https://github.com/FastyBird/simple-auth)
- Multilingual
- JS integration via [Vuex ORM](https://vuex-orm.org) plugin
- Python integration via [SQLAlchemy](https://www.sqlalchemy.org)
- Integrated connector worker for Python based connectors & PHP based connectors

## Requirements

PHP part of [FastyBird](https://www.fastybird.com) devices module is tested against PHP 7.4
and [ReactPHP http](https://github.com/reactphp/http) 0.8 event-driven, streaming plaintext HTTP server
and [Nette framework](https://nette.org/en/) 3.0 PHP framework for real programmers

JavaScript part of [FastyBird](https://www.fastybird.com) devices module is tested
against [ECMAScript 6](https://www.w3schools.com/JS/js_es6.asp)

Python part of [FastyBird](https://www.fastybird.com) devices module is tested against [Python 3.7](http://python.org)

## Installation

#### Application backend in PHP

The best way to install **fastybird/devices-module** is using [Composer](http://getcomposer.org/):

```sh
composer require fastybird/devices-module
```

#### Application frontend in JS

The best way to install **@fastybird/devices-module** is using [Yarn](https://yarnpkg.com/):

```sh
yarn add @fastybird/devices-module
```

or if you prefer npm:

```sh
npm install @fastybird/devices-module
```

#### Application workers in Python

The best way to install **fastybird-devices-module** is using [pip](https://pip.pypa.io/):

```sh
pip install fastybird-devices-module
```

## Documentation

Learn how to use devices module and manage your connectors & devices
in [documentation](https://github.com/FastyBird/devices-module/blob/master/.docs/en/index.md).

## Feedback

Use the [issue tracker](https://github.com/FastyBird/devices-module/issues) for bugs
or [mail](mailto:code@fastybird.com) or [Tweet](https://twitter.com/fastybird) us for any idea that can improve the
project.

Thank you for testing, reporting and contributing.

## Changelog

For release info check [release page](https://github.com/FastyBird/devices-module/releases)

## Maintainers

<table>
	<tbody>
		<tr>
			<td align="center">
				<a href="https://github.com/akadlec">
					<img width="80" height="80" src="https://avatars3.githubusercontent.com/u/1866672?s=460&amp;v=4">
				</a>
				<br>
				<a href="https://github.com/akadlec">Adam Kadlec</a>
			</td>
		</tr>
	</tbody>
</table>

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/fastybird/devices-module](https://github.com/fastybird/devices-module).

==> fastybird-devices-module-0.75.0.tar.gz: fastybird-devices-module-0.75.0/README.md <==
# FastyBird IoT devices module

[![Build Status](https://badgen.net/github/checks/FastyBird/devices-module/main?cache=300&style=flat-square)](https://github.com/FastyBird/devices-module/actions)
[![Licence](https://badgen.net/github/license/FastyBird/devices-module?cache=300&style=flat-square)](https://github.com/FastyBird/devices-module/blob/main/LICENSE.md)
[![Code coverage](https://badgen.net/coveralls/c/github/FastyBird/devices-module?cache=300&style=flat-square)](https://coveralls.io/r/FastyBird/devices-module)

![PHP](https://badgen.net/packagist/php/FastyBird/devices-module?cache=300&style=flat-square)
[![PHP latest stable](https://badgen.net/packagist/v/FastyBird/devices-module/latest?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/devices-module)
[![PHP downloads total](https://badgen.net/packagist/dt/FastyBird/devices-module?cache=300&style=flat-square)](https://packagist.org/packages/FastyBird/devices-module)
[![PHPStan](https://img.shields.io/badge/phpstan-enabled-brightgreen.svg?style=flat-square)](https://github.com/phpstan/phpstan)

![JS](https://img.shields.io/badge/js-es6-blue.svg?style=flat-square)
[![JS latest stable](https://badgen.net/npm/v/@fastybird/devices-module?cache=300&style=flat-square)](https://www.npmjs.com/package/@fastybird/devices-module)
[![JS downloads total](https://badgen.net/npm/dt/@fastybird/devices-module?cache=300&style=flat-square)](https://www.npmjs.com/package/@fastybird/devices-module)
![Types](https://badgen.net/npm/types/@fastybird/devices-module?cache=300&style=flat-square)

![Python](https://badgen.net/pypi/python/fastybird-devices-module?cache=300&style=flat-square)
[![Python latest stable](https://badgen.net/pypi/v/fastybird-devices-module?cache=300&style=flat-square)](https://pypi.org/project/fastybird-devices-module/)
[![Python downloads month](https://img.shields.io/pypi/dm/fastybird-devices-module?cache=300&style=flat-square)](https://pypi.org/project/fastybird-devices-module/)
[![Black](https://img.shields.io/badge/black-enabled-brightgreen.svg?style=flat-square)](https://github.com/psf/black)
[![MyPy](https://img.shields.io/badge/mypy-enabled-brightgreen.svg?style=flat-square)](http://mypy-lang.org)

## What is FastyBird IoT devices module?

Devices module is a combined [Nette framework](https://nette.org) extension, [Vuex ORM](https://vuex-orm.org) plugin
and also [Python](https://python.org) module for managing connectors and connected devices and their basic logic.

[FastyBird](https://www.fastybird.com) [IoT](https://en.wikipedia.org/wiki/Internet_of_things) devices module is
an [Apache2 licensed](http://www.apache.org/licenses/LICENSE-2.0) distributed extension, developed
in [PHP](https://www.php.net) with [Nette framework](https://nette.org), in [Typescript](https://www.typescriptlang.org)
and also in [Python](https://python.org).

### Features:

- Devices connectors management
- Devices and channels management
- Support for data [exchange bus](https://github.com/FastyBird/exchange)
- [{JSON:API}](https://jsonapi.org/) schemas for full api access
- User access [check & validation](https://github.com/FastyBird/simple-auth)
- Multilingual
- JS integration via [Vuex ORM](https://vuex-orm.org) plugin
- Python integration via [SQLAlchemy](https://www.sqlalchemy.org)
- Integrated connector worker for Python based connectors & PHP based connectors

## Requirements

PHP part of [FastyBird](https://www.fastybird.com) devices module is tested against PHP 7.4
and [ReactPHP http](https://github.com/reactphp/http) 0.8 event-driven, streaming plaintext HTTP server
and [Nette framework](https://nette.org/en/) 3.0 PHP framework for real programmers

JavaScript part of [FastyBird](https://www.fastybird.com) devices module is tested
against [ECMAScript 6](https://www.w3schools.com/JS/js_es6.asp)

Python part of [FastyBird](https://www.fastybird.com) devices module is tested against [Python 3.7](http://python.org)

## Installation

#### Application backend in PHP

The best way to install **fastybird/devices-module** is using [Composer](http://getcomposer.org/):

```sh
composer require fastybird/devices-module
```

#### Application frontend in JS

The best way to install **@fastybird/devices-module** is using [Yarn](https://yarnpkg.com/):

```sh
yarn add @fastybird/devices-module
```

or if you prefer npm:

```sh
npm install @fastybird/devices-module
```

#### Application workers in Python

The best way to install **fastybird-devices-module** is using [pip](https://pip.pypa.io/):

```sh
pip install fastybird-devices-module
```

## Documentation

Learn how to use devices module and manage your connectors & devices
in [documentation](https://github.com/FastyBird/devices-module/blob/main/.docs/en/index.md).

## Feedback

Use the [issue tracker](https://github.com/FastyBird/devices-module/issues) for bugs
or [mail](mailto:code@fastybird.com) or [Tweet](https://twitter.com/fastybird) us for any idea that can improve the
project.

Thank you for testing, reporting and contributing.

## Changelog

For release info check [release page](https://github.com/FastyBird/devices-module/releases)

## Maintainers

<table>
	<tbody>
		<tr>
			<td align="center">
				<a href="https://github.com/akadlec">
					<img width="80" height="80" src="https://avatars3.githubusercontent.com/u/1866672?s=460&amp;v=4">
				</a>
				<br>
				<a href="https://github.com/akadlec">Adam Kadlec</a>
			</td>
		</tr>
	</tbody>
</table>

***
Homepage [https://www.fastybird.com](https://www.fastybird.com) and
repository [https://github.com/fastybird/devices-module](https://github.com/fastybird/devices-module).
